==> apache-geode-1.12.5-src.tgz: apache-geode-1.12.5-src/geode-pulse/src/main/java/org/apache/geode/tools/pulse/internal/service/ClusterDiskThroughputService.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 *
 */

package org.apache.geode.tools.pulse.internal.service;

import javax.servlet.http.HttpServletRequest;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ObjectNode;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Service;

import org.apache.geode.tools.pulse.internal.data.Cluster;
import org.apache.geode.tools.pulse.internal.data.Repository;

/**
 * Class ClusterDiskThroughput This class contains implementations for getting cluster's current
 * disk throughput details and its trend over time
 *
 * @since GemFire version 7.0.Beta
 */

@Component
@Service("ClusterDiskThroughput")
@Scope("singleton")
public class ClusterDiskThroughputService implements PulseService {

  private final ObjectMapper mapper = new ObjectMapper();

  @Override
  public ObjectNode execute(final HttpServletRequest request) throws Exception {

    // get cluster object
    Cluster cluster = Repository.get().getCluster();

    // json object to be sent as response
    ObjectNode responseJSON = mapper.createObjectNode();

    // cluster's Throughout Writes trend added to json response object
    // CircularFifoBuffer throughoutWritesTrend =
    // cluster.getThroughoutWritesTrend();
    double currentThroughputWrites = cluster.getDiskWritesRate();
    double currentThroughputReads = cluster.getDiskReadsRate();

    responseJSON.put("currentThroughputReads", currentThroughputReads);
    responseJSON.put("throughputReads",
        mapper.valueToTree(cluster.getStatisticTrend(Cluster.CLUSTER_STAT_THROUGHPUT_READS)));

    responseJSON.put("currentThroughputWrites", currentThroughputWrites);
    responseJSON.put("throughputWrites",
        mapper.valueToTree(cluster.getStatisticTrend(Cluster.CLUSTER_STAT_THROUGHPUT_WRITES)));

    // Send json response
    return responseJSON;
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-pulse/src/main/java/org/apache/geode/tools/pulse/internal/service/ClusterDiskThroughputService.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 *
 */

package org.apache.geode.tools.pulse.internal.service;

import javax.servlet.http.HttpServletRequest;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ObjectNode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Service;

import org.apache.geode.tools.pulse.internal.data.Cluster;
import org.apache.geode.tools.pulse.internal.data.Repository;

/**
 * Class ClusterDiskThroughput This class contains implementations for getting cluster's current
 * disk throughput details and its trend over time
 *
 * @since GemFire version 7.0.Beta
 */

@Component
@Service("ClusterDiskThroughput")
@Scope("singleton")
public class ClusterDiskThroughputService implements PulseService {

  private final ObjectMapper mapper = new ObjectMapper();
  private final Repository repository;

  @Autowired
  public ClusterDiskThroughputService(Repository repository) {
    this.repository = repository;
  }

  @Override
  public ObjectNode execute(final HttpServletRequest request) throws Exception {

    // get cluster object
    Cluster cluster = repository.getCluster();

    // json object to be sent as response
    ObjectNode responseJSON = mapper.createObjectNode();

    // cluster's Throughout Writes trend added to json response object
    // CircularFifoBuffer throughoutWritesTrend =
    // cluster.getThroughoutWritesTrend();
    double currentThroughputWrites = cluster.getDiskWritesRate();
    double currentThroughputReads = cluster.getDiskReadsRate();

    responseJSON.put("currentThroughputReads", currentThroughputReads);
    responseJSON.set("throughputReads",
        mapper.valueToTree(cluster.getStatisticTrend(Cluster.CLUSTER_STAT_THROUGHPUT_READS)));

    responseJSON.put("currentThroughputWrites", currentThroughputWrites);
    responseJSON.set("throughputWrites",
        mapper.valueToTree(cluster.getStatisticTrend(Cluster.CLUSTER_STAT_THROUGHPUT_WRITES)));

    // Send json response
    return responseJSON;
  }
}
